@@ -126,7 +126,7 @@ def check_and_sync_columns(df ,table_name, database, max_new=5):
 
 # ===================== DataFrame 入库 =====================
 
-def update_datas(df,db_cols, table_name, database):
+def update_datas(df, table_name, database):
 
     conn = None
     for i in range(2):
@@ -157,7 +157,7 @@ def update_datas(df,db_cols, table_name, database):
                 conn.rollback()
             print("入库失败:", e)
             if '1054, "Unknown column' in str(e):
-                check_and_sync_columns(df,db_cols,table_name,database)
+                check_and_sync_columns(df,table_name,database)
         finally:
             if conn:
                 conn.close()
